%==========================================================================
% Prameters 
%==========================================================================
ind=1000;
spells=10;
% B - HSINC
parameters_BHSINC = parameters_ew('B','HSINC');
% W - HSINC
parameters_WHSINC = parameters_ew('W','HSINC');
% B - HSGRD
parameters_BHSGRD = parameters_ew('B','HSGRD');
% W - HSGRD
parameters_WHSGRD = parameters_ew('W','HSGRD');
% B - COLINC
parameters_BCOLINC = parameters_ew('B','COLINC');
% W - COLINC
parameters_WCOLINC = parameters_ew('W','COLINC');
% W - COLGRD
parameters_WCOLGRD = parameters_ew('W','COLGRD');
%==========================================================================
% get simulated data 
%==========================================================================
[wage_BHSINC,duration_BHSINC] = simulation_ew(parameters_BHSINC,1234,spells,ind);
[wage_BHSGRD,duration_BHSGRD] = simulation_ew(parameters_BHSGRD,1234,spells,ind);
[wage_BCOLINC,duration_BCOLINC] = simulation_ew(parameters_BCOLINC,1234,spells,ind);
[wage_WHSINC,duration_WHSINC] = simulation_ew(parameters_WHSINC,1234,spells,ind);
[wage_WHSGRD,duration_WHSGRD] = simulation_ew(parameters_WHSGRD,1234,spells,ind);
[wage_WCOLINC,duration_WCOLINC] = simulation_ew(parameters_WCOLINC,1234,spells,ind);
[wage_WCOLGRD,duration_WCOLGRD] = simulation_ew(parameters_WCOLGRD,1234,spells,ind);

% find percentiles of wage distribution
wL = prctile([wage_BHSINC(:);wage_BHSGRD(:);wage_BCOLINC(:);wage_WHSINC(:);wage_WHSGRD(:);wage_WCOLINC(:);wage_WCOLGRD(:)],25);
wH = prctile([wage_BHSINC(:);wage_BHSGRD(:);wage_BCOLINC(:);wage_WHSINC(:);wage_WHSGRD(:);wage_WCOLINC(:);wage_WCOLGRD(:)],75);

% create wage dummies
wage_BHSINC_L = (wage_BHSINC <= wL);
wage_BHSINC_M = (wage_BHSINC > wL).*(wage_BHSINC <= wH);
wage_BHSINC_H = (wage_BHSINC > wH);

wage_BHSGRD_L = (wage_BHSGRD <= wL);
wage_BHSGRD_M = (wage_BHSGRD > wL).*(wage_BHSGRD <= wH);
wage_BHSGRD_H = (wage_BHSGRD > wH);

wage_BCOLINC_L = (wage_BCOLINC <= wL);
wage_BCOLINC_M = (wage_BCOLINC > wL).*(wage_BCOLINC <= wH);
wage_BCOLINC_H = (wage_BCOLINC > wH);

wage_WHSINC_L = (wage_WHSINC <= wL);
wage_WHSINC_M = (wage_WHSINC > wL).*(wage_WHSINC <= wH);
wage_WHSINC_H = (wage_WHSINC > wH);

wage_WHSGRD_L = (wage_WHSGRD <= wL);
wage_WHSGRD_M = (wage_WHSGRD > wL).*(wage_WHSGRD <= wH);
wage_WHSGRD_H = (wage_WHSGRD > wH);

wage_WCOLINC_L = (wage_WCOLINC <= wL);
wage_WCOLINC_M = (wage_WCOLINC > wL).*(wage_WCOLINC <= wH);
wage_WCOLINC_H = (wage_WCOLINC > wH);

wage_WCOLGRD_L = (wage_WCOLGRD <= wL);
wage_WCOLGRD_M = (wage_WCOLGRD > wL).*(wage_WCOLGRD <= wH);
wage_WCOLGRD_H = (wage_WCOLGRD > wH);

% create final data set - arrange and include dummy for gender
data_BHSINC = [];
data_BHSGRD = [];
data_BCOLINC = [];
data_WHSINC = [];
data_WHSGRD = [];
data_WCOLINC = [];
data_WCOLGRD = [];

for k = 1:spells
    % data layout: [duration,wageL,wageM,wageH,black,HSGRD,COLINC,COLGRD]
    data_BHSINC = [data_BHSINC,[duration_BHSINC(:,k),wage_BHSINC_L(:,k),wage_BHSINC_M(:,k),wage_BHSINC_H(:,k),ones(ind,1),zeros(ind,1),zeros(ind,1),zeros(ind,1)]];
    data_BHSGRD = [data_BHSGRD,[duration_BHSGRD(:,k),wage_BHSGRD_L(:,k),wage_BHSGRD_M(:,k),wage_BHSGRD_H(:,k),ones(ind,1),ones(ind,1),zeros(ind,1),zeros(ind,1)]];
    data_BCOLINC = [data_BCOLINC,[duration_BCOLINC(:,k),wage_BCOLINC_L(:,k),wage_BCOLINC_M(:,k),wage_BCOLINC_H(:,k),ones(ind,1),zeros(ind,1),ones(ind,1),zeros(ind,1)]];
    data_WHSINC = [data_WHSINC,[duration_WHSINC(:,k),wage_WHSINC_L(:,k),wage_WHSINC_M(:,k),wage_WHSINC_H(:,k),zeros(ind,1),zeros(ind,1),zeros(ind,1),zeros(ind,1)]];
    data_WHSGRD = [data_WHSGRD,[duration_WHSGRD(:,k),wage_WHSGRD_L(:,k),wage_WHSGRD_M(:,k),wage_WHSGRD_H(:,k),zeros(ind,1),ones(ind,1),zeros(ind,1),zeros(ind,1)]];
    data_WCOLINC = [data_WCOLINC,[duration_WCOLINC(:,k),wage_WCOLINC_L(:,k),wage_WCOLINC_M(:,k),wage_WCOLINC_H(:,k),zeros(ind,1),zeros(ind,1),ones(ind,1),zeros(ind,1)]];
    data_WCOLGRD = [data_WCOLGRD,[duration_WCOLGRD(:,k),wage_WCOLGRD_L(:,k),wage_WCOLGRD_M(:,k),wage_WCOLGRD_H(:,k),zeros(ind,1),zeros(ind,1),zeros(ind,1),ones(ind,1)]];
end
data = [data_BHSINC;data_BHSGRD;data_BCOLINC;data_WHSINC;data_WHSGRD;data_WCOLINC;data_WCOLGRD];


%==========================================================================
% estimate
%==========================================================================

% estimate using the exponential hazard 

% ---------------
% 2 types
% ---------------
% init_guess = [(1/8)*ones(1,8),0.15*ones(1,18)];
%     
% Aeq = [ones(1,8),zeros(1,18)];
% beq = 1;
% lb = [.0000001*ones(8,1);.000001*ones(6,1);-20*ones(12,1)];
% ub = [.9999999*ones(8,1); 10000*ones(3,1);10*ones(3,1);20*ones(12,1)];
% 
% options = optimset('MaxIter',10000,'MaxFunEvals',30000,'Algorithm','interior-point','UseParallel','always');
% 
% log_like_6_2types(init_guess,data)
% 
% [ests,log_likelihood,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_6_2types(z,data),init_guess,[],[],Aeq,beq,lb,ub,[],options);%solve with constraint lb = 0
% 
% save('ew_exp_2types')

% ---------------
% 3 types
% ---------------
% init_guess = [(1/27)*ones(1,27),1.01269477704343,0.220031908493266,0.0524750540502142,0.0352030299338329,0,0.109254184113936,0,0.0446461932432434,0,-0.271468686945157,0.365949388806645,-1.75593117059183,-0.905778283358297,-0.614453683963101,0.958774156831071,1.87241238684231,0.661412678186082,-0.936368868716679,1.05675683822269,3.28771938969194,2.17693461325866];
%     
% Aeq = [ones(1,27),zeros(1,21)];
% beq = 1;
% lb = [.0000001*ones(27,1);.000001*ones(9,1);-20*ones(12,1)];
% ub = [.9999999*ones(27,1); 10000*ones(3,1);10*ones(6,1);20*ones(12,1)];
% 
% options = optimset('MaxIter',10000,'MaxFunEvals',30000,'Algorithm','interior-point','UseParallel','always');
% 
% log_like_6_3types(init_guess,data)
% 
% [ests,log_likelihood,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_6_3types(z,data),init_guess,[],[],Aeq,beq,lb,ub,[],options);%solve with constraint lb = 0
% 
% save('ew_exp_3types')
% ---------------
% 4 types
% ---------------
% init_guess = [(1/64)*ones(1,64),0.745279703030945,0.237402654181889,0.290258463782241,0.0647108111143257,4.98339689058563e-05,1,0.0251688917903278,0.189937412211482,1,0.00630324419284535,0.153861344123853,1,-0.529385641921935,0.331905263672623,-1.22233332576765,-0.594282013469010,-0.350529593786694,0.799966216489718,1.56929729824623,0.669786760897743,-0.607766759088654,0.901241737358243,1.36437704495398,0.803789044142548];
% init_guess2 = [1.03266212678008e-07,0.5*(0.0121062774382370),0.5*(0.0121062774382370),0.0311042966849594,1.01247665379419e-07,0.00720120672922506,1.01116571352298e-07,1.01222290231502e-07,1.01378465325586e-07,1.02936097853279e-07,8.01658056633408e-05,1.01455026811643e-07,0.0433466416446447,1.01319213313600e-07,1.02476062754798e-07,0.00617917447953788,0.00331151767917207,0.0218897170366021,0.222844802042326,0.00865701472639024,1.02430581216939e-07,0.0875370106774537,1.00994250327487e-07,1.01955890128208e-07,1.02646860455998e-07,0.199079502168400,0.00686416837341224,1.01803333409315e-07,0.0531539371772767,1.01800853031839e-07,1.02524474782970e-07,0.0156469534145907,1.04887935239751e-07,0.00240497639746043,0.0689190895646559,0.00222609861398725,0.000322155620424369,1.00914358478836e-07,0.00399902536420031,0.0725139259291275,1.04725775946330e-07,0.0213518941917040,0.0528131649190603,0.0141892872386674,1.13828492504738e-07,1.03542800184594e-07,1.02930903397072e-07,1.09575299928922e-07,1.01123825263987e-07,1.01577629238010e-07,1.01961879055987e-07,1.01873543954917e-07,1.00963842885882e-07,0.00826286876717891,1.01220421513883e-07,1.01070398223569e-07,1.00997029663570e-07,0.000141610634610549,1.01582742895911e-07,1.02592732879312e-07,0.0338497192684523,1.02157273126045e-07,1.02964020038748e-07,1.03168632381942e-07,0.183961883491975,0.206335705041361,0.355152338566698,0.216053703060144,0.00107882546671215,9.29408349388999,0.0209568744738146,0.247778723574635,4.60808957004096,0.00336216599842012,0.0919004858023074,0.366098762405615,-0.301549929352311,0.419783818556363,1.19803415632700,-0.568412966508778,-0.190445231213588,0.561493784301636,0.534015127255622,0.717203909982519,-0.292323355252229,1.07216045088448,1.46079237597856,1.59728753648697];
% Aeq = [ones(1,64),zeros(1,24)];
% beq = 1;
% lb = [.0000001*ones(64,1);.000001*ones(12,1);-6*ones(12,1)];
% ub = [.9999999*ones(64,1); 10000*ones(3,1);10*ones(9,1);6*ones(12,1)];
% 
% options = optimset('MaxIter',10000,'MaxFunEvals',30000,'Algorithm','interior-point','UseParallel','always');
% 
% log_like_6_4types(init_guess2,data)
% 
% [ests2,log_likelihood2,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_6_4types(z,data),init_guess2,[],[],Aeq,beq,lb,ub,[],options);%solve with constraint lb = 0
% 
% save('ew_exp_4types')

% ---------------
% 5 types
% ---------------
% init_guess = [(1/125)*ones(1,125),0.183961883491975,0.206335705041361,0.355152338566698,0.216053703060144,0.00107882546671215,9.29408349388999,0,0.0209568744738146,0.247778723574635,4.60808957004096,0,0.00336216599842012,0.0919004858023074,0.366098762405615,0,-0.301549929352311,0.419783818556363,1.19803415632700,-0.568412966508778,-0.190445231213588,0.561493784301636,0.534015127255622,0.717203909982519,-0.292323355252229,1.07216045088448,1.46079237597856,1.59728753648697];
% init_guess2 = [1.37694357865707e-06,1.27663204200369e-06,2.17766785039929e-06,9.73278568813984e-06,0.00231218417141567,6.74119864104941e-07,0.00408656960556695,1.72825700185209e-06,2.55337404880886e-06,1.06245391090337e-06,7.29313485384459e-07,1.07477348575961e-06,1.04942237586636e-06,2.98878843270239e-06,1.37929198364276e-06,0.0143165572646818,7.93976757703262e-07,9.21210531857314e-07,9.25644923017034e-05,1.53845597600395e-06,3.42644119468242e-05,6.12257336467760e-06,1.41100566251750e-05,0.0248984826027455,0.00531036099903573,6.84631411554356e-07,1.83142450049246e-05,0.148231160381540,5.58521309867168e-06,1.38215610540297e-05,6.73088691336199e-07,0.0764083131062354,8.69881923491331e-07,1.71551214420774e-06,9.13917684755561e-07,6.73166459399739e-07,0.107226243343144,0.0498883318168243,2.64946521199502e-06,1.64208627056182e-06,1.72418728872735e-06,7.67836569912151e-07,9.19898988089950e-07,3.66025383674447e-05,1.60602650613800e-06,7.67057224921650e-07,3.09791494912968e-06,5.84560806950905e-06,0.0771526145583244,7.37178441570833e-06,6.74198128321472e-07,0.000481265299320988,0.0119377588320342,0.0237713400224387,1.73886422496855e-05,6.73807170269473e-07,6.71318111509324e-07,0.00662521267577362,0.0411103649692089,0.0238199833685346,6.72896186187726e-07,0.0212810259668566,0.0141996455278590,0.0446302807090196,0.000960188698874296,1.42995343384542e-06,7.79312008841787e-07,9.23138992563352e-07,1.30944614760665e-05,1.53323060919721e-06,7.11804376858437e-07,5.20112875629273e-05,1.85960643342627e-05,0.0532627429424695,0.0184408033910482,8.49244477644810e-07,1.23636580427863e-06,9.80232195659449e-07,1.18284768439944e-06,1.37464788487354e-06,7.19313051794551e-07,0.00829476697902877,1.11232449169676e-06,7.75785927128960e-07,8.05229772786857e-07,7.51907267071792e-07,0.000133094533085446,1.18228876129308e-06,1.61596442958490e-06,1.83417297659483e-06,0.0367649891370721,7.88229340593948e-06,8.68855566841774e-06,2.24762896857826e-05,1.09467308828633e-05,1.04685497616129e-06,9.16126341211106e-07,1.01579804900069e-06,1.10244903177680e-06,1.20914710824219e-06,7.05306973175888e-07,3.96555036571252e-06,1.73059569129782e-05,6.02219682554922e-06,0.0698996293254837,6.72899340749483e-07,0.0152791271690076,1.00134922199874e-06,1.25602278231501e-06,8.31584499449283e-07,6.75502328591303e-07,0.0243532729676999,3.76708229736297e-06,3.19764813669251e-06,2.02727977483657e-06,2.06081160607279e-06,7.64427572522650e-07,9.17799744791035e-07,0.000241582248017970,1.63071988757522e-06,8.37548941263134e-07,2.48213123894044e-06,5.25936990742074e-06,0.0673913659377812,0.00677213095441173,0.267858880615833,0.120305135025202,0.620150386499395,0.131959051204773,9.16148067408650e-05,6.13427824090148,0.251040802246338,0.0297990423620276,0.289523843971624,9.99984126342658,2.44444478145606,0.000388793721561384,0.0114472489767580,0.0858148834180390,0.0407268434406069,-0.279308120258029,0.414572456678743,1.26428304160746,-0.556795593034261,-0.0564710853265838,0.579666025844104,1.28464251020668,0.934397971184264,-0.0213567144978507,0.842367568557803,2.88412907614064,2.50313010223154];
% init_guess3 = [1.06448004299936e-07,1.12611108553751e-07,0.00257833004620591,1.17659025743235e-07,0.000825614996504281,1.05717902828260e-07,0.00117093472459133,1.19942170774553e-07,0.000144366756160913,1.18715719012629e-07,1.05817305262876e-07,5.59521563534669e-05,1.14101859215837e-07,1.18329977810560e-07,1.25606756277062e-07,0.0206579383634369,1.08064454444273e-07,1.09403821009990e-07,2.38191201854300e-06,1.15906055671391e-07,1.08612105171226e-07,1.15249166073496e-07,0.00153073066832329,0.000970657944940223,0.00224857851262249,1.05761970406637e-07,1.74273520567038e-07,0.202153608919903,1.42019563251712e-07,0.000720996546688383,1.05918115671480e-07,0.0825954185835422,1.07059577729417e-07,1.08610313673777e-07,1.12260683830511e-07,1.05779321555662e-07,0.140669900797722,0.0378301657497311,1.12374160439258e-07,1.29741188562139e-07,1.32819197207259e-07,1.06626079802786e-07,1.08109725256652e-07,0.000598130226226332,1.15034763892745e-07,1.06179955919656e-07,1.28144545197423e-07,1.50594036102049e-07,0.100158069602391,0.0425161481656518,1.05746074169825e-07,0.000276487706685423,0.0150271695731789,0.0304187169093335,1.54843073461533e-07,1.06986955482959e-07,1.05714636277688e-07,0.00379126479104067,1.14183792611732e-07,0.0726182601078463,1.06062181642442e-07,0.0216302841470210,0.0136483986764190,0.00966108183048305,0.0232291082982719,1.26342855211911e-07,1.06773526231082e-07,1.08132114719480e-07,5.49035514583683e-07,1.14256956444885e-07,1.05889443037447e-07,0.000137786519809068,2.78577562480022e-07,0.0173828824795629,0.0393288839881010,1.07137179734880e-07,1.09035909677540e-07,1.08250603216618e-07,1.06203192369406e-07,1.08533018791889e-07,1.06227175041753e-07,0.00808414952496369,1.07420079590161e-07,1.05763267811088e-07,1.06262560647160e-07,1.06477258993976e-07,1.58048226899199e-07,1.08519225655967e-07,1.05877759516075e-07,1.09539679525420e-07,0.0298781292276395,1.64297906860582e-07,1.69379103668989e-07,2.23822537800855e-07,1.84433701567990e-07,1.08574457881251e-07,1.06986010032694e-07,1.08752998966917e-07,1.07473324469424e-07,1.08720516206472e-07,1.05900564790131e-07,1.25308512850007e-07,0.00469399499221538,1.20344511931308e-07,0.0202264635474380,1.05717032106520e-07,0.00715663903973095,1.08890625928685e-07,1.07258166010602e-07,1.08081504660132e-07,1.05734918365341e-07,1.38054146860685e-07,1.26162044207604e-07,1.09140684211133e-07,1.17657632435794e-07,1.57332163707805e-07,1.06588488196588e-07,1.08063728933794e-07,0.000433911689667768,1.15070733332320e-07,1.06866015560821e-07,1.15438689200963e-07,1.38714674919825e-07,0.0382100750643456,0.00672748911586152,0.487482234611796,0.103938372040353,0.512846316152141,0.0779501544471791,0.000127469084329928,3.85377274862958,0.280957292398703,0.0269743643142099,0.282541481774547,9.99999882381410,2.60446474885686,0.000440527965343807,0.0136818662011020,0.118580474439558,0.0497361309502486,-0.280652064203646,0.417952074924491,1.28554629888009,-0.664838036598229,0.0603748425207796,0.677435197956327,1.28879275181908,1.23845463562889,0.199674186757619,1.08517180916274,2.78935302304838,3.13895997966241];
% Aeq = [ones(1,125),zeros(1,27)];
% beq = 1;
% lb = [.0000001*ones(125,1);.000001*ones(15,1);-6*ones(12,1)];
% ub = [.9999999*ones(125,1); 10000*ones(3,1);10*ones(12,1);6*ones(12,1)];
% 
% options = optimset('MaxIter',10000,'MaxFunEvals',30000,'Algorithm','interior-point','UseParallel','always');
% 
% log_like_6_5types(init_guess3,data)
% 
% [ests3,log_likelihood3,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_6_5types(z,data),init_guess3,[],[],Aeq,beq,lb,ub,[],options);%solve with constraint lb = 0
% 
% save('ew_exp_5types')

% ---------------
% estimate using the weibull hazard
% ---------------
% init_guess = [(1/125)*ones(1,125),0.5*ones(1,30)];
% 
% Aeq = [ones(1,125),zeros(1,30)];
% beq = 1;
% lb = [.0000001*ones(125,1);.000001*ones(18,1);-2*ones(12,1)];
% ub = [.9999999*ones(125,1); 10000*ones(3,1);20*ones(3,1);10*ones(12,1);2*ones(12,1)];
% 
% options = optimset('MaxIter',10000,'MaxFunEvals',30000,'Algorithm','interior-point','UseParallel','always');
% 
% log_like_7_5types(init_guess,data)
% 
% [ests,log_likelihood,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_7_5types(z,data),init_guess,[],[],Aeq,beq,lb,ub,[],options);%solve with constraint lb = 0

%% 
%==========================================================================
% compare estimates to parameters
%==========================================================================

% Find the expected hazard rate over types from EW model and estimates
ew_haz_BHSINC = parameters_BHSINC(1)*parameters_BHSINC(2)*(1-normcdf((log(0.5*parameters_BHSINC(4)) - (log(0.5)+parameters_BHSINC(3)))/(parameters_BHSINC(23)*sqrt(parameters_BHSINC(22)+parameters_BHSINC(21)))))+...
                parameters_BHSINC(5)*parameters_BHSINC(6)*(1-normcdf((log(0.5*parameters_BHSINC(8)) - (log(0.5)+parameters_BHSINC(7)))/(parameters_BHSINC(23)*sqrt(parameters_BHSINC(22)+parameters_BHSINC(21)))))+...
                parameters_BHSINC(9)*parameters_BHSINC(10)*(1-normcdf((log(0.5*parameters_BHSINC(12)) - (log(0.5)+parameters_BHSINC(11)))/(parameters_BHSINC(23)*sqrt(parameters_BHSINC(22)+parameters_BHSINC(21)))))+...
                parameters_BHSINC(13)*parameters_BHSINC(14)*(1-normcdf((log(0.5*parameters_BHSINC(16)) - (log(0.5)+parameters_BHSINC(15)))/(parameters_BHSINC(23)*sqrt(parameters_BHSINC(22)+parameters_BHSINC(21)))))+...
                parameters_BHSINC(17)*parameters_BHSINC(18)*(1-normcdf((log(0.5*parameters_BHSINC(20)) - (log(0.5)+parameters_BHSINC(19)))/(parameters_BHSINC(23)*sqrt(parameters_BHSINC(22)+parameters_BHSINC(21)))));
            
ew_haz_BHSGRD = parameters_BHSGRD(1)*parameters_BHSGRD(2)*(1-normcdf((log(0.5*parameters_BHSGRD(4)) - (log(0.5)+parameters_BHSGRD(3)))/(parameters_BHSGRD(23)*sqrt(parameters_BHSGRD(22)+parameters_BHSGRD(21)))))+...
                parameters_BHSGRD(5)*parameters_BHSGRD(6)*(1-normcdf((log(0.5*parameters_BHSGRD(8)) - (log(0.5)+parameters_BHSGRD(7)))/(parameters_BHSGRD(23)*sqrt(parameters_BHSGRD(22)+parameters_BHSGRD(21)))))+...
                parameters_BHSGRD(9)*parameters_BHSGRD(10)*(1-normcdf((log(0.5*parameters_BHSGRD(12)) - (log(0.5)+parameters_BHSGRD(11)))/(parameters_BHSGRD(23)*sqrt(parameters_BHSGRD(22)+parameters_BHSGRD(21)))))+...
                parameters_BHSGRD(13)*parameters_BHSGRD(14)*(1-normcdf((log(0.5*parameters_BHSGRD(16)) - (log(0.5)+parameters_BHSGRD(15)))/(parameters_BHSGRD(23)*sqrt(parameters_BHSGRD(22)+parameters_BHSGRD(21)))))+...
                parameters_BHSGRD(17)*parameters_BHSGRD(18)*(1-normcdf((log(0.5*parameters_BHSGRD(20)) - (log(0.5)+parameters_BHSGRD(19)))/(parameters_BHSGRD(23)*sqrt(parameters_BHSGRD(22)+parameters_BHSGRD(21)))));
            
ew_haz_BCOLINC = parameters_BCOLINC(1)*parameters_BCOLINC(2)*(1-normcdf((log(0.5*parameters_BCOLINC(4)) - (log(0.5)+parameters_BCOLINC(3)))/(parameters_BCOLINC(23)*sqrt(parameters_BCOLINC(22)+parameters_BCOLINC(21)))))+...
                parameters_BCOLINC(5)*parameters_BCOLINC(6)*(1-normcdf((log(0.5*parameters_BCOLINC(8)) - (log(0.5)+parameters_BCOLINC(7)))/(parameters_BCOLINC(23)*sqrt(parameters_BCOLINC(22)+parameters_BCOLINC(21)))))+...
                parameters_BCOLINC(9)*parameters_BCOLINC(10)*(1-normcdf((log(0.5*parameters_BCOLINC(12)) - (log(0.5)+parameters_BCOLINC(11)))/(parameters_BCOLINC(23)*sqrt(parameters_BCOLINC(22)+parameters_BCOLINC(21)))))+...
                parameters_BCOLINC(13)*parameters_BCOLINC(14)*(1-normcdf((log(0.5*parameters_BCOLINC(16)) - (log(0.5)+parameters_BCOLINC(15)))/(parameters_BCOLINC(23)*sqrt(parameters_BCOLINC(22)+parameters_BCOLINC(21)))))+...
                parameters_BCOLINC(17)*parameters_BCOLINC(18)*(1-normcdf((log(0.5*parameters_BCOLINC(20)) - (log(0.5)+parameters_BCOLINC(19)))/(parameters_BCOLINC(23)*sqrt(parameters_BCOLINC(22)+parameters_BCOLINC(21)))));
            
ew_haz_WHSINC = parameters_WHSINC(1)*parameters_WHSINC(2)*(1-normcdf((log(0.5*parameters_WHSINC(4)) - (log(0.5)+parameters_WHSINC(3)))/(parameters_WHSINC(23)*sqrt(parameters_WHSINC(22)+parameters_WHSINC(21)))))+...
                parameters_WHSINC(5)*parameters_WHSINC(6)*(1-normcdf((log(0.5*parameters_WHSINC(8)) - (log(0.5)+parameters_WHSINC(7)))/(parameters_WHSINC(23)*sqrt(parameters_WHSINC(22)+parameters_WHSINC(21)))))+...
                parameters_WHSINC(9)*parameters_WHSINC(10)*(1-normcdf((log(0.5*parameters_WHSINC(12)) - (log(0.5)+parameters_WHSINC(11)))/(parameters_WHSINC(23)*sqrt(parameters_WHSINC(22)+parameters_WHSINC(21)))))+...
                parameters_WHSINC(13)*parameters_WHSINC(14)*(1-normcdf((log(0.5*parameters_WHSINC(16)) - (log(0.5)+parameters_WHSINC(15)))/(parameters_WHSINC(23)*sqrt(parameters_WHSINC(22)+parameters_WHSINC(21)))))+...
                parameters_WHSINC(17)*parameters_WHSINC(18)*(1-normcdf((log(0.5*parameters_WHSINC(20)) - (log(0.5)+parameters_WHSINC(19)))/(parameters_WHSINC(23)*sqrt(parameters_WHSINC(22)+parameters_WHSINC(21)))));
            
ew_haz_WHSGRD = parameters_WHSGRD(1)*parameters_WHSGRD(2)*(1-normcdf((log(0.5*parameters_WHSGRD(4)) - (log(0.5)+parameters_WHSGRD(3)))/(parameters_WHSGRD(23)*sqrt(parameters_WHSGRD(22)+parameters_WHSGRD(21)))))+...
                parameters_WHSGRD(5)*parameters_WHSGRD(6)*(1-normcdf((log(0.5*parameters_WHSGRD(8)) - (log(0.5)+parameters_WHSGRD(7)))/(parameters_WHSGRD(23)*sqrt(parameters_WHSGRD(22)+parameters_WHSGRD(21)))))+...
                parameters_WHSGRD(9)*parameters_WHSGRD(10)*(1-normcdf((log(0.5*parameters_WHSGRD(12)) - (log(0.5)+parameters_WHSGRD(11)))/(parameters_WHSGRD(23)*sqrt(parameters_WHSGRD(22)+parameters_WHSGRD(21)))))+...
                parameters_WHSGRD(13)*parameters_WHSGRD(14)*(1-normcdf((log(0.5*parameters_WHSGRD(16)) - (log(0.5)+parameters_WHSGRD(15)))/(parameters_WHSGRD(23)*sqrt(parameters_WHSGRD(22)+parameters_WHSGRD(21)))))+...
                parameters_WHSGRD(17)*parameters_WHSGRD(18)*(1-normcdf((log(0.5*parameters_WHSGRD(20)) - (log(0.5)+parameters_WHSGRD(19)))/(parameters_WHSGRD(23)*sqrt(parameters_WHSGRD(22)+parameters_WHSGRD(21)))));
            
ew_haz_WCOLINC = parameters_WCOLINC(1)*parameters_WCOLINC(2)*(1-normcdf((log(0.5*parameters_WCOLINC(4)) - (log(0.5)+parameters_WCOLINC(3)))/(parameters_WCOLINC(23)*sqrt(parameters_WCOLINC(22)+parameters_WCOLINC(21)))))+...
                parameters_WCOLINC(5)*parameters_WCOLINC(6)*(1-normcdf((log(0.5*parameters_WCOLINC(8)) - (log(0.5)+parameters_WCOLINC(7)))/(parameters_WCOLINC(23)*sqrt(parameters_WCOLINC(22)+parameters_WCOLINC(21)))))+...
                parameters_WCOLINC(9)*parameters_WCOLINC(10)*(1-normcdf((log(0.5*parameters_WCOLINC(12)) - (log(0.5)+parameters_WCOLINC(11)))/(parameters_WCOLINC(23)*sqrt(parameters_WCOLINC(22)+parameters_WCOLINC(21)))))+...
                parameters_WCOLINC(13)*parameters_WCOLINC(14)*(1-normcdf((log(0.5*parameters_WCOLINC(16)) - (log(0.5)+parameters_WCOLINC(15)))/(parameters_WCOLINC(23)*sqrt(parameters_WCOLINC(22)+parameters_WCOLINC(21)))))+...
                parameters_WCOLINC(17)*parameters_WCOLINC(18)*(1-normcdf((log(0.5*parameters_WCOLINC(20)) - (log(0.5)+parameters_WCOLINC(19)))/(parameters_WCOLINC(23)*sqrt(parameters_WCOLINC(22)+parameters_WCOLINC(21)))));
            
ew_haz_WCOLGRD = parameters_WCOLGRD(1)*parameters_WCOLGRD(2)*(1-normcdf((log(0.5*parameters_WCOLGRD(4)) - (log(0.5)+parameters_WCOLGRD(3)))/(parameters_WCOLGRD(23)*sqrt(parameters_WCOLGRD(22)+parameters_WCOLGRD(21)))))+...
                parameters_WCOLGRD(5)*parameters_WCOLGRD(6)*(1-normcdf((log(0.5*parameters_WCOLGRD(8)) - (log(0.5)+parameters_WCOLGRD(7)))/(parameters_WCOLGRD(23)*sqrt(parameters_WCOLGRD(22)+parameters_WCOLGRD(21)))))+...
                parameters_WCOLGRD(9)*parameters_WCOLGRD(10)*(1-normcdf((log(0.5*parameters_WCOLGRD(12)) - (log(0.5)+parameters_WCOLGRD(11)))/(parameters_WCOLGRD(23)*sqrt(parameters_WCOLGRD(22)+parameters_WCOLGRD(21)))))+...
                parameters_WCOLGRD(13)*parameters_WCOLGRD(14)*(1-normcdf((log(0.5*parameters_WCOLGRD(16)) - (log(0.5)+parameters_WCOLGRD(15)))/(parameters_WCOLGRD(23)*sqrt(parameters_WCOLGRD(22)+parameters_WCOLGRD(21)))))+...
                parameters_WCOLGRD(17)*parameters_WCOLGRD(18)*(1-normcdf((log(0.5*parameters_WCOLGRD(20)) - (log(0.5)+parameters_WCOLGRD(19)))/(parameters_WCOLGRD(23)*sqrt(parameters_WCOLGRD(22)+parameters_WCOLGRD(21)))));

%  Find the expected hazard from our estimates
cov_BHSINC = [1,0,0,0];
cov_BHSGRD = [1,1,0,0];
cov_BCOLINC = [1,0,1,0];
cov_WHSINC = [0,0,0,0];
cov_WHSGRD = [0,1,0,0];
cov_WCOLINC = [0,0,1,0];
cov_WCOLGRD = [0,0,0,1];
% ---------------------------
% 2 types
% ---------------------------
% lamL = ests(9);
% lamM = ests(10);
% lamH = ests(11);
% 
% V1L = ests(12);
% V1M = ests(13);
% V1H = ests(14);
% 
% beta1 = ests(15);
% beta2 = ests(16);
% beta3 = ests(17);
% beta4 = ests(18);
% beta5 = ests(19);
% beta6 = ests(20);
% beta7 = ests(21);
% beta8 = ests(22);
% beta9 = ests(23);
% beta10 = ests(24);
% beta11 = ests(25);
% beta12 = ests(26);
% 
% 
% BetaL = [ beta1, beta2, beta3, beta4]';
% BetaM = [ beta5, beta6, beta7, beta8]';
% BetaH = [ beta9, beta10,beta11,beta12]';
% 
% 
% %create matrix of unbservable types
% types = permn([1,2],3);
% types(types(:,1) == 2,1) = V1L;
% types(types(:,2) == 2,2) = V1M;
% types(types(:,3) == 2,3) = V1H;
% 
% est_haz_BHSINC = ests(1:8)*sum(types.*repmat([lamL*exp(cov_BHSINC*BetaL), lamM*exp(cov_BHSINC*BetaM), lamH*exp(cov_BHSINC*BetaH)],8,1),2);
% est_haz_BHSGRD = ests(1:8)*sum(types.*repmat([lamL*exp(cov_BHSGRD*BetaL), lamM*exp(cov_BHSGRD*BetaM), lamH*exp(cov_BHSGRD*BetaH)],8,1),2);
% est_haz_BCOLINC = ests(1:8)*sum(types.*repmat([lamL*exp(cov_BCOLINC*BetaL), lamM*exp(cov_BCOLINC*BetaM), lamH*exp(cov_BCOLINC*BetaH)],8,1),2);
% est_haz_WHSINC = ests(1:8)*sum(types.*repmat([lamL*exp(cov_WHSINC*BetaL), lamM*exp(cov_WHSINC*BetaM), lamH*exp(cov_WHSINC*BetaH)],8,1),2);
% est_haz_WHSGRD = ests(1:8)*sum(types.*repmat([lamL*exp(cov_WHSGRD*BetaL), lamM*exp(cov_WHSGRD*BetaM), lamH*exp(cov_WHSGRD*BetaH)],8,1),2);
% est_haz_WCOLINC = ests(1:8)*sum(types.*repmat([lamL*exp(cov_WCOLINC*BetaL), lamM*exp(cov_WCOLINC*BetaM), lamH*exp(cov_WCOLINC*BetaH)],8,1),2);
% est_haz_WCOLGRD = ests(1:8)*sum(types.*repmat([lamL*exp(cov_WCOLGRD*BetaL), lamM*exp(cov_WCOLGRD*BetaM), lamH*exp(cov_WCOLGRD*BetaH)],8,1),2);

% ---------------------------
% 3 types
% ---------------------------
% lamL = ests(28);
% lamM = ests(29);
% lamH = ests(30);
% 
% V1L = ests(31);
% V2L = ests(32);
% 
% V1M = ests(33);
% V2M = ests(34);
% 
% V1H = ests(35);
% V2H = ests(36);
% 
% beta1 = ests(37);
% beta2 = ests(38);
% beta3 = ests(39);
% beta4 = ests(40);
% beta5 = ests(41);
% beta6 = ests(42);
% beta7 = ests(43);
% beta8 = ests(44);
% beta9 = ests(45);
% beta10 = ests(46);
% beta11 = ests(47);
% beta12 = ests(48);
% 
% 
% BetaL = [ beta1, beta2, beta3, beta4]';
% BetaM = [ beta5, beta6, beta7, beta8]';
% BetaH = [ beta9, beta10,beta11,beta12]';
% 
% %create matrix of unbservable types
% types = permn([1,2,3],3);
% types(types(:,1) == 2,1) = V1L;
% types(types(:,1) == 3,1) = V2L;
% types(types(:,2) == 2,2) = V1M;
% types(types(:,2) == 3,2) = V2M;
% types(types(:,3) == 2,3) = V1H;
% types(types(:,3) == 3,3) = V2H;
% 
% est_haz_BHSINC  = ests(1:27)*sum(types.*repmat([lamL*exp(cov_BHSINC*BetaL), lamM*exp(cov_BHSINC*BetaM), lamH*exp(cov_BHSINC*BetaH)],27,1),2);
% est_haz_BHSGRD  = ests(1:27)*sum(types.*repmat([lamL*exp(cov_BHSGRD*BetaL), lamM*exp(cov_BHSGRD*BetaM), lamH*exp(cov_BHSGRD*BetaH)],27,1),2);
% est_haz_BCOLINC = ests(1:27)*sum(types.*repmat([lamL*exp(cov_BCOLINC*BetaL), lamM*exp(cov_BCOLINC*BetaM), lamH*exp(cov_BCOLINC*BetaH)],27,1),2);
% est_haz_WHSINC  = ests(1:27)*sum(types.*repmat([lamL*exp(cov_WHSINC*BetaL), lamM*exp(cov_WHSINC*BetaM), lamH*exp(cov_WHSINC*BetaH)],27,1),2);
% est_haz_WHSGRD  = ests(1:27)*sum(types.*repmat([lamL*exp(cov_WHSGRD*BetaL), lamM*exp(cov_WHSGRD*BetaM), lamH*exp(cov_WHSGRD*BetaH)],27,1),2);
% est_haz_WCOLINC = ests(1:27)*sum(types.*repmat([lamL*exp(cov_WCOLINC*BetaL), lamM*exp(cov_WCOLINC*BetaM), lamH*exp(cov_WCOLINC*BetaH)],27,1),2);
% est_haz_WCOLGRD = ests(1:27)*sum(types.*repmat([lamL*exp(cov_WCOLGRD*BetaL), lamM*exp(cov_WCOLGRD*BetaM), lamH*exp(cov_WCOLGRD*BetaH)],27,1),2);

% ---------------------------
% 4 types
% ---------------------------
% lamL = ests(65);
% lamM = ests(66);
% lamH = ests(67);
% 
% V1L = ests(68);
% V2L = ests(69);
% V3L = ests(70);
% 
% V1M = ests(71);
% V2M = ests(72);
% V3M = ests(73);
% 
% V1H = ests(74);
% V2H = ests(75);
% V3H = ests(76);
% 
% beta1 = ests(77);
% beta2 = ests(78);
% beta3 = ests(79);
% beta4 = ests(80);
% beta5 = ests(81);
% beta6 = ests(82);
% beta7 = ests(83);
% beta8 = ests(84);
% beta9 = ests(85);
% beta10 = ests(86);
% beta11 = ests(87);
% beta12 = ests(88);
% 
% 
% BetaL = [ beta1, beta2, beta3, beta4]';
% BetaM = [ beta5, beta6, beta7, beta8]';
% BetaH = [ beta9, beta10,beta11,beta12]';
% 
% %create matrix of unbservable types
% types = permn([1,2,3,4],3);
% types(types(:,1) == 2,1) = V1L;
% types(types(:,1) == 3,1) = V2L;
% types(types(:,1) == 4,1) = V3L;
% types(types(:,2) == 2,2) = V1M;
% types(types(:,2) == 3,2) = V2M;
% types(types(:,2) == 4,2) = V3M;
% types(types(:,3) == 2,3) = V1H;
% types(types(:,3) == 3,3) = V2H;
% types(types(:,3) == 4,3) = V3H;
% 
% est_haz_BHSINC = ests(1:64)*sum(types.*repmat([lamL*exp(cov_BHSINC*BetaL), lamM*exp(cov_BHSINC*BetaM), lamH*exp(cov_BHSINC*BetaH)],64,1),2);
% est_haz_BHSGRD = ests(1:64)*sum(types.*repmat([lamL*exp(cov_BHSGRD*BetaL), lamM*exp(cov_BHSGRD*BetaM), lamH*exp(cov_BHSGRD*BetaH)],64,1),2);
% est_haz_BCOLINC = ests(1:64)*sum(types.*repmat([lamL*exp(cov_BCOLINC*BetaL), lamM*exp(cov_BCOLINC*BetaM), lamH*exp(cov_BCOLINC*BetaH)],64,1),2);
% est_haz_WHSINC = ests(1:64)*sum(types.*repmat([lamL*exp(cov_WHSINC*BetaL), lamM*exp(cov_WHSINC*BetaM), lamH*exp(cov_WHSINC*BetaH)],64,1),2);
% est_haz_WHSGRD = ests(1:64)*sum(types.*repmat([lamL*exp(cov_WHSGRD*BetaL), lamM*exp(cov_WHSGRD*BetaM), lamH*exp(cov_WHSGRD*BetaH)],64,1),2);
% est_haz_WCOLINC = ests(1:64)*sum(types.*repmat([lamL*exp(cov_WCOLINC*BetaL), lamM*exp(cov_WCOLINC*BetaM), lamH*exp(cov_WCOLINC*BetaH)],64,1),2);
% est_haz_WCOLGRD = ests(1:64)*sum(types.*repmat([lamL*exp(cov_WCOLGRD*BetaL), lamM*exp(cov_WCOLGRD*BetaM), lamH*exp(cov_WCOLGRD*BetaH)],64,1),2);

% ---------------------------
% 5 types
% ---------------------------
% beta1 = ests(141);
% beta2 = ests(142);
% beta3 = ests(143);
% beta4 = ests(144);
% beta5 = ests(145);
% beta6 = ests(146);
% beta7 = ests(147);
% beta8 = ests(148);
% beta9 = ests(149);
% beta10 = ests(150);
% beta11 = ests(151);
% beta12 = ests(152);
% 
% BetaL = [ beta1, beta2, beta3, beta4]';
% BetaM = [ beta5, beta6, beta7, beta8]';
% BetaH = [ beta9, beta10,beta11,beta12]';
% 
% V1L = ests(129);
% V2L = ests(130);
% V3L = ests(131);
% V4L = ests(132);
% 
% V1M = ests(133);
% V2M = ests(134);
% V3M = ests(135);
% V4M = ests(136);
% 
% V1H = ests(137);
% V2H = ests(138);
% V3H = ests(139);
% V4H = ests(140);
% 
% lamL = ests(126);
% lamM = ests(127);
% lamH = ests(128);
% 
% %create matrix of unbservable types
% types = permn([1,2,3,4,5],3);
% types(types(:,1) == 2,1) = V1L;
% types(types(:,1) == 3,1) = V2L;
% types(types(:,1) == 4,1) = V3L;
% types(types(:,1) == 5,1) = V4L;
% types(types(:,2) == 2,2) = V1M;
% types(types(:,2) == 3,2) = V2M;
% types(types(:,2) == 4,2) = V3M;
% types(types(:,2) == 5,2) = V4M;
% types(types(:,3) == 2,3) = V1H;
% types(types(:,3) == 3,3) = V2H;
% types(types(:,3) == 4,3) = V3H;
% types(types(:,3) == 5,3) = V4H;
% 
% est_haz_BHSINC = ests(1:125)*sum(types.*repmat([lamL*exp(cov_BHSINC*BetaL), lamM*exp(cov_BHSINC*BetaM), lamH*exp(cov_BHSINC*BetaH)],125,1),2);
% est_haz_BHSGRD = ests(1:125)*sum(types.*repmat([lamL*exp(cov_BHSGRD*BetaL), lamM*exp(cov_BHSGRD*BetaM), lamH*exp(cov_BHSGRD*BetaH)],125,1),2);
% est_haz_BCOLINC = ests(1:125)*sum(types.*repmat([lamL*exp(cov_BCOLINC*BetaL), lamM*exp(cov_BCOLINC*BetaM), lamH*exp(cov_BCOLINC*BetaH)],125,1),2);
% est_haz_WHSINC = ests(1:125)*sum(types.*repmat([lamL*exp(cov_WHSINC*BetaL), lamM*exp(cov_WHSINC*BetaM), lamH*exp(cov_WHSINC*BetaH)],125,1),2);
% est_haz_WHSGRD = ests(1:125)*sum(types.*repmat([lamL*exp(cov_WHSGRD*BetaL), lamM*exp(cov_WHSGRD*BetaM), lamH*exp(cov_WHSGRD*BetaH)],125,1),2);
% est_haz_WCOLINC = ests(1:125)*sum(types.*repmat([lamL*exp(cov_WCOLINC*BetaL), lamM*exp(cov_WCOLINC*BetaM), lamH*exp(cov_WCOLINC*BetaH)],125,1),2);
% est_haz_WCOLGRD = ests(1:125)*sum(types.*repmat([lamL*exp(cov_WCOLGRD*BetaL), lamM*exp(cov_WCOLGRD*BetaM), lamH*exp(cov_WCOLGRD*BetaH)],125,1),2);

%------------------------------
% matrix that compares hazard rates
%------------------------------

% hazard_rates = [ew_haz_BHSINC,est_haz_BHSINC;...
%                 ew_haz_BHSGRD,est_haz_BHSGRD;...
%                 ew_haz_BCOLINC,est_haz_BCOLINC;...
%                 ew_haz_WHSINC,est_haz_WHSINC;...
%                 ew_haz_WHSGRD,est_haz_WHSGRD;...
%                 ew_haz_WCOLINC,est_haz_WCOLINC;...
%                 ew_haz_WCOLGRD,est_haz_WCOLGRD];


%%
%------------------------------
% Find the KL diverence
%------------------------------
% for 2 types
KL2_BHSINC = KLdiv(parameters_BHSINC,'BHSINC','2',1234,150000);
KL2_BHSGRD = KLdiv(parameters_BHSGRD,'BHSGRD','2',1234,150000);
KL2_BCOLINC = KLdiv(parameters_BCOLINC,'BCOLINC','2',1234,150000);
KL2_WHSINC = KLdiv(parameters_WHSINC,'WHSINC','2',1234,150000);
KL2_WHSGRD = KLdiv(parameters_WHSGRD,'WHSGRD','2',1234,150000);
KL2_WCOLINC = KLdiv(parameters_WCOLINC,'WCOLINC','2',1234,150000);
KL2_WCOLGRD = KLdiv(parameters_WCOLGRD,'WCOLGRD','2',1234,150000);

% for 3 types
KL3_BHSINC = KLdiv(parameters_BHSINC,'BHSINC','3',1234,150000);
KL3_BHSGRD = KLdiv(parameters_BHSGRD,'BHSGRD','3',1234,150000);
KL3_BCOLINC = KLdiv(parameters_BCOLINC,'BCOLINC','3',1234,150000);
KL3_WHSINC = KLdiv(parameters_WHSINC,'WHSINC','3',1234,150000);
KL3_WHSGRD = KLdiv(parameters_WHSGRD,'WHSGRD','3',1234,150000);
KL3_WCOLINC = KLdiv(parameters_WCOLINC,'WCOLINC','3',1234,150000);
KL3_WCOLGRD = KLdiv(parameters_WCOLGRD,'WCOLGRD','3',1234,150000);

% for 3 types
[A1,B1,C1,other3_BHSINC] = KLdiv(parameters_BHSINC,'BHSINC','3',1234,150000);
[A2,B2,C2,other3_BHSGRD] = KLdiv(parameters_BHSGRD,'BHSGRD','3',1234,150000);
[A3,B3,C3,other3_BCOLINC] = KLdiv(parameters_BCOLINC,'BCOLINC','3',1234,150000);
[A4,B4,C4,other3_WHSINC] = KLdiv(parameters_WHSINC,'WHSINC','3',1234,150000);
[A5,B5,C5,other3_WHSGRD] = KLdiv(parameters_WHSGRD,'WHSGRD','3',1234,150000);
[A6,B6,C6,other3_WCOLINC] = KLdiv(parameters_WCOLINC,'WCOLINC','3',1234,150000);
[A7,B7,C7,other3_WCOLGRD] = KLdiv(parameters_WCOLGRD,'WCOLGRD','3',1234,150000);

% for 4 types
KL4_BHSINC = KLdiv(parameters_BHSINC,'BHSINC','4',1234,150000);
KL4_BHSGRD = KLdiv(parameters_BHSGRD,'BHSGRD','4',1234,150000);
KL4_BCOLINC = KLdiv(parameters_BCOLINC,'BCOLINC','4',1234,150000);
KL4_WHSINC = KLdiv(parameters_WHSINC,'WHSINC','4',1234,150000);
KL4_WHSGRD = KLdiv(parameters_WHSGRD,'WHSGRD','4',1234,150000);
KL4_WCOLINC = KLdiv(parameters_WCOLINC,'WCOLINC','4',1234,150000);
KL4_WCOLGRD = KLdiv(parameters_WCOLGRD,'WCOLGRD','4',1234,150000);

% for 5 types
KL5_BHSINC = KLdiv(parameters_BHSINC,'BHSINC','5',1234,150000);
KL5_BHSGRD = KLdiv(parameters_BHSGRD,'BHSGRD','5',1234,150000);
KL5_BCOLINC = KLdiv(parameters_BCOLINC,'BCOLINC','5',1234,150000);
KL5_WHSINC = KLdiv(parameters_WHSINC,'WHSINC','5',1234,150000);
KL5_WHSGRD = KLdiv(parameters_WHSGRD,'WHSGRD','5',1234,150000);
KL5_WCOLINC = KLdiv(parameters_WCOLINC,'WCOLINC','5',1234,150000);
KL5_WCOLGRD = KLdiv(parameters_WCOLGRD,'WCOLGRD','5',1234,150000);

