%==========================================================================
% Prameters 
%==========================================================================
ind=1000;
spells=10;
%--------------------------------------------------------------------------
% Male
%--------------------------------------------------------------------------
lambda_m = 0.278;             
mu_m = 2.342;
sigma_m = 0.554;
alpha_m = 0.427;
res_m = 3.313;
parameters_m = [lambda_m,mu_m,sigma_m,alpha_m,res_m];
%--------------------------------------------------------------------------
% Female
%--------------------------------------------------------------------------
lambda_f = 0.356;            
mu_f = 2.273;
sigma_f = 0.479;
alpha_f = 0.429;
res_f = 2.798;
parameters_f = [lambda_f,mu_f,sigma_f,alpha_f,res_f];
%==========================================================================
% get simulated data for men and women
%==========================================================================
[wage_m,duration_m] = simulation_flinn(parameters_m,1234,spells,ind);
[wage_f,duration_f] = simulation_flinn(parameters_f,1234,spells,ind);

% find percentiles of wage distribution
wL = prctile([wage_m(:);wage_f(:)],25);
wH = prctile([wage_m(:);wage_f(:)],75);

% create wage dummies
wage_mL = (wage_m <= wL);
wage_mM = (wage_m > wL).*(wage_m <= wH);
wage_mH = (wage_m > wH);

wage_fL = (wage_f <= wL);
wage_fM = (wage_f > wL).*(wage_f <= wH);
wage_fH = (wage_f > wH);

% create final data set - arrange and include dummy for gender
data_m = [];
data_f = [];

for k = 1:spells
   data_m = [data_m,[duration_m(:,k),wage_mL(:,k),wage_mM(:,k),wage_mH(:,k),ones(ind,1)]];
   data_f = [data_f,[duration_f(:,k),wage_fL(:,k),wage_fM(:,k),wage_fH(:,k),zeros(ind,1)]];
end
data = [data_m;data_f];


%==========================================================================
% estimate
%==========================================================================

init_guess = 0.2*ones(1,6);

Aeq = [];
beq = [];
lb = [zeros(1,3),-inf,-inf,-inf];
ub = [];

options = optimset('MaxIter',10000,'MaxFunEvals',25000,'Algorithm','interior-point');

log_like_6(init_guess,data)

[ests,log_likelihood,exitflag,output,lambda,grad,hess] =  fmincon(@(z) log_like_6(z,data),init_guess,[],[],Aeq,beq,lb,ub,[],options);

%==========================================================================
% calculate expected duration from estimated parameters
%==========================================================================
lamL = ests(1);
lamM = ests(2);
lamH = ests(3);

beta1 = ests(4);
beta2 = ests(5);
beta3 = ests(6);

lam_male = lamL.*exp(1*beta1)+lamM.*exp(1*beta2)+lamH.*exp(1*beta3)
lam_female = lamL.*exp(0*beta1)+lamM.*exp(0*beta2)+lamH.*exp(0*beta3)







