function [ wage,duration ] = simulation_ew( parameters, seed, spells, ind )
% simulated duration data using estimates from eckstein and wulpin
rng(seed)
% assign parameters
gamma1 = parameters(1);
Prob1 =  parameters(2);
mu1 =    parameters(3);
res_m1 = parameters(4);
gamma2 = parameters(5);
Prob2 =  parameters(6);
mu2 =    parameters(7);
res_m2 = parameters(8);
gamma3 = parameters(9);
Prob3 =  parameters(10);
mu3 =    parameters(11);
res_m3 = parameters(12);
gamma4 = parameters(13);
Prob4 =  parameters(14);
mu4 =    parameters(15);
res_m4 = parameters(16);
gamma5 = parameters(17);
Prob5 =  parameters(18);
mu5 =    parameters(19);
res_m5 = parameters(20);
var_m =  parameters(21);
var_u =  parameters(22);
rho =    parameters(23);

% find total variance and sd
sigma_m = sqrt(var_m);
var_t = var_m+var_u;
sigma_t = sqrt(var_t);

% draw types
typedraws = unifrnd(0,1,ind,1);

type = zeros(ind,5);
type(:,1) = (typedraws<=gamma1);
type(:,2) = (typedraws<=(gamma1+gamma2)).*(typedraws>gamma1);
type(:,3) = (typedraws<=(gamma1+gamma2+gamma3)).*(typedraws>(gamma1+gamma2));
type(:,4) = (typedraws<=(gamma1+gamma2+gamma3+gamma4)).*(typedraws>(gamma1+gamma2+gamma3));
type(:,5) = (typedraws>=(gamma1+gamma2+gamma3+gamma4));

%--------------------------------------------------------------------------
% draw wages 
%--------------------------------------------------------------------------
% change reservation match value to cdf value
res_m1_cdf = logncdf(res_m1,mu1,sigma_m);
res_m2_cdf = logncdf(res_m2,mu2,sigma_m);
res_m3_cdf = logncdf(res_m3,mu3,sigma_m);
res_m4_cdf = logncdf(res_m4,mu4,sigma_m);
res_m5_cdf = logncdf(res_m5,mu5,sigma_m);

% draw from truncated uniform
wagedraws1 = unifrnd(res_m1_cdf,1,ind,spells);
wagedraws2 = unifrnd(res_m2_cdf,1,ind,spells);
wagedraws3 = unifrnd(res_m3_cdf,1,ind,spells);
wagedraws4 = unifrnd(res_m4_cdf,1,ind,spells);
wagedraws5 = unifrnd(res_m5_cdf,1,ind,spells);

% calculate wage from truncted uniform draw
wage1 = 0.5*logninv(wagedraws1,mu1,sigma_m);
wage2 = 0.5*logninv(wagedraws2,mu2,sigma_m);
wage3 = 0.5*logninv(wagedraws3,mu3,sigma_m);
wage4 = 0.5*logninv(wagedraws4,mu4,sigma_m);
wage5 = 0.5*logninv(wagedraws5,mu5,sigma_m);

% draw measurement error
error = normrnd(0,sqrt(var_u),ind,spells);

wage1 = exp(log(wage1) + error);
wage2 = exp(log(wage2) + error);
wage3 = exp(log(wage3) + error);
wage4 = exp(log(wage4) + error);
wage5 = exp(log(wage5) + error);

% find final wage given type
wage = repmat(type(:,1),1,spells).*wage1 + repmat(type(:,2),1,spells).*wage2 + repmat(type(:,3),1,spells).*wage3 + repmat(type(:,4),1,spells).*wage4 + repmat(type(:,5),1,spells).*wage5;

%--------------------------------------------------------------------------
% duration draws
%--------------------------------------------------------------------------
durationdraws = unifrnd(0,1,ind,spells);

% solve for duration
duration1 = log(1-durationdraws)./log(1-Prob1.*(1-normcdf((log(0.5*res_m1) - (log(0.5) + mu1))/(rho*sigma_t))));
duration2 = log(1-durationdraws)./log(1-Prob2.*(1-normcdf((log(0.5*res_m2) - (log(0.5) + mu2))/(rho*sigma_t))));
duration3 = log(1-durationdraws)./log(1-Prob3.*(1-normcdf((log(0.5*res_m3) - (log(0.5) + mu3))/(rho*sigma_t))));
duration4 = log(1-durationdraws)./log(1-Prob4.*(1-normcdf((log(0.5*res_m4) - (log(0.5) + mu4))/(rho*sigma_t))));
duration5 = log(1-durationdraws)./log(1-Prob5.*(1-normcdf((log(0.5*res_m5) - (log(0.5) + mu5))/(rho*sigma_t))));

% find final duration given type
duration = repmat(type(:,1),1,spells).*duration1 + repmat(type(:,2),1,spells).*duration2 + repmat(type(:,3),1,spells).*duration3 + repmat(type(:,4),1,spells).*duration4 + repmat(type(:,5),1,spells).*duration5;
end

